@@ -2,16 +2,16 @@
 package Require::HookChain;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-05-03'; # DATE
+our $DATE = '2023-07-23'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 #IFUNBUILT
 # use strict;
 # use warnings;
 #END IFUNBUILT
 
-# be minimalistic, use our own blessed()
+# be minimalistic, use our own blessed() so we don't have to load any module (in this case, Scalar::Util)
 unless (defined &blessed) {
     *blessed = sub { my $arg = shift; my $ref = ref $arg; $ref && $ref !~ /\A(SCALAR|ARRAY|HASH|GLOB|Regexp)\z/ };
 }
@@ -105,6 +105,7 @@ sub import {
             if ($end) {
                 push @INC, $c_hook;
             } else {
+                # install the hook after uss
                 splice @INC, 1, 0, $c_hook;
             }
             last;
@@ -150,7 +151,7 @@ Require::HookChain - Chainable require hooks
 
 =head1 VERSION
 
-This document describes version 0.014 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-05-03.
+This document describes version 0.015 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-07-23.
 
 =head1 SYNOPSIS
 
@@ -161,18 +162,28 @@ F<Require/HookChain/munge/prepend.pm>:
  package Require::HookChain::munge::prepend;
 
  sub new {
+
+     # our hook accepts one argument: preamble (the string to be prepended)
      my ($class, $preamble) = @_;
+
      bless { preamble => $preamble }, $class;
  }
 
  sub Require::HookChain::munge::prepend::INC {
+
+     # instead a filename like a reguler hook, an hook's INC is called by
+     # Require::HookChain's main INC and will be passed $r stash
      my ($self, $r) = @_;
 
      # safety, in case we are not called by Require::HookChain
      return () unless ref $r;
 
      my $src = $r->src;
+
+     # we only munge source code, when source code has not been loaded by other
+     # hooks, we decline.
      return unless defined $src;
+
      $src = "$self->{preamble};\n$src";
      $r->src($src);
  }
@@ -181,13 +192,13 @@ F<Require/HookChain/munge/prepend.pm>:
 
 In a code to use this hook:
 
- use Require::HookChain 'munge::prepend' => 'use strict';
+ use Require::HookChain -end=>1, 'munge::prepend' => 'use strict';
  use Foo::Bar; # Foo/Bar.pm will be loaded with added 'use strict;' at the start
 
 Install other hooks, but put it at the end of C<@INC> instead of at the
 beginning:
 
- use Require::HookChain -end => 1, append => 'some code';
+ use Require::HookChain -end=>1, 'munge::append' => 'some code';
  use Require::HookChain 'log::stderr'; # log each loading of module to stderr
 
 =head1 DESCRIPTION
@@ -246,6 +257,42 @@ Bool. If set to true, then debug messages will be printed to stderr.
 
 =back
 
+=head2 Hook ordering
+
+The order of execution of hooks by Require::HookChain is by their order in
+C<@INC>, so you should set the ordering yourself by way of the (reverse)
+ordering of C<< use Require::HookChain >> statements. Each time you do this:
+
+ use Require::HookChain 'hook1';
+
+then Require::HookChain will (re)install its own hook to the beginning of
+C<@INC>, then insert C<hook1> as the second element in C<@INC>. Then when you
+load another hook:
+
+ use Require::HookChain 'hook2';
+
+then Require::HookChain will (re)install its own hook to the beginning of
+C<@INC>, then insert C<hook2> as the second element in C<@INC>, while C<hook1>
+will be at the third element of C<@INC>. So the order of hook execution will be:
+C<< hook2, hook1 >>. When another hook, C<hook3>, is loaded afterwards, the
+order of execution will be C<< hook3, hook2, hook1 >>.
+
+Some hooks should be loaded at the end of other hooks (and sources), e.g.
+L<debug::dump_source::stderr|Require::HookChain::debug::dump_source::stderr>, so
+you should install such hooks using something like:
+
+ use Require::HookChain -end=>1, 'hook4';
+
+in which case Require::HookChain will again (re)install its own hook to the
+beginning of C<@INC>, then insert C<hook4> as the last element in C<@INC>. The
+order of execution of hooks will then be: C<< hook3, hook2, hook1, hook4 >>. If
+you install another hook at the end:
+
+ use Require::HookChain -end=>1, 'hook5';
+
+then the order of execution of hooks will then be: C<< hook3, hook2, hook1,
+hook4, hook5 >>.
+
 =head2 Subnamespace organization
 
 =over
@@ -255,12 +302,6 @@ Bool. If set to true, then debug messages will be printed to stderr.
 Hooks that do debugging-related stuffs. See also: C<log::> subnamespace,
 C<timestamp::> subnamespace.
 
-=item * Require::HookChain::filter::
-
-Hooks that filter module loading due to some criteria. These hooks can fail a
-module being loaded even though the source is available, if the additional
-criteria are not met.
-
 =item * Require::HookChain::log::
 
 Hooks that add logging to module loading process. See also: C<debug::>
@@ -270,6 +311,16 @@ subnamespace.
 
 Hooks that modify source code.
 
+=item * Require::HookChain::postcheck::
+
+Hooks that perform checks after the source code is loaded (eval-ed). See also
+C<precheck::> subnamespace.
+
+=item * Require::HookChain::precheck::
+
+Hooks that perform checks before the source code is loaded (eval-ed).
+See also C<postcheck::> subnamespace.
+
 =item * Require::HookChain::source::
 
 Hooks that allow loading module source from alternative sources.
@@ -316,7 +367,12 @@ Make sure you use a hook this way:
 
 instead of:
 
- use Require::HookChain::hookname; # INCORRECT
+ use Require::HookChain::hookname; # INCORRECT, this does not install the hook to @INC
+
+=head2 The order of execution of hooks is incorrect!
+
+You control the ordering by putting the hooks in C<@INC> in your preferred
+order. See L</"Hook ordering"> for more details.
 
 =head1 HOMEPAGE
 
@@ -330,6 +386,8 @@ Source repository is at L<https://github.com/perlancar/perl-Require-HookChain>.
 
 L<RHC> for convenience of using on the command-line or one-liners.
 
+L<Require::Hook> is an older framework and is superseded by Require::HookChain.q
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
