@@ -7,9 +7,9 @@ package Require::HookChain::source::test::code;
 #END IFUNBUILT
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-05-03'; # DATE
+our $DATE = '2023-07-23'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 sub new {
     my ($class, $code) = @_;
@@ -22,7 +22,8 @@ sub Require::HookChain::source::test::code::INC {
     # safety, in case we are not called by Require::HookChain
     return () unless ref $r;
 
-    $self->{code}->($r);
+    $r->src($self->{code}->($r));
+    1;
 }
 
 1;
@@ -40,7 +41,7 @@ Require::HookChain::source::test::code - Specify a code to provide source code
 
 =head1 VERSION
 
-This document describes version 0.014 of Require::HookChain::source::test::code (from Perl distribution Require-HookChain), released on 2023-05-03.
+This document describes version 0.015 of Require::HookChain::source::test::code (from Perl distribution Require-HookChain), released on 2023-07-23.
 
 =head1 SYNOPSIS
 
